@@ -1,4 +1,4 @@
-/*	$OpenBSD: roa.c,v 1.69 2023/06/29 10:28:25 tb Exp $ */
+/*	$OpenBSD: roa.c,v 1.70 2023/09/25 11:08:45 tb Exp $ */
 /*
  * Copyright (c) 2022 Theo Buehler <tb@openbsd.org>
  * Copyright (c) 2019 Kristaps Dzonsons <kristaps@bsd.lv>
@@ -208,7 +208,8 @@ roa_parse_econtent(const unsigned char *d, size_t dsz, struct parse *p)
  * Returns the ROA or NULL if the document was malformed.
  */
 struct roa *
-roa_parse(X509 **x509, const char *fn, const unsigned char *der, size_t len)
+roa_parse(X509 **x509, const char *fn, int talid, const unsigned char *der,
+    size_t len)
 {
 	struct parse	 p;
 	size_t		 cmsz;
