@@ -1,4 +1,4 @@
-/*	$OpenBSD: tak.c,v 1.11 2023/06/29 10:28:25 tb Exp $ */
+/*	$OpenBSD: tak.c,v 1.12 2023/09/25 11:08:45 tb Exp $ */
 /*
  * Copyright (c) 2022 Job Snijders <job@fastly.com>
  * Copyright (c) 2022 Theo Buehler <tb@openbsd.org>
@@ -225,7 +225,8 @@ tak_parse_econtent(const unsigned char *d, size_t dsz, struct parse *p)
  * Returns the TAK or NULL if the object was malformed.
  */
 struct tak *
-tak_parse(X509 **x509, const char *fn, const unsigned char *der, size_t len)
+tak_parse(X509 **x509, const char *fn, int talid, const unsigned char *der,
+    size_t len)
 {
 	struct parse		 p;
 	struct cert		*cert = NULL;
